@@ -720,45 +720,47 @@ int main(int argc,char **argv)
         {
           if (strncmp("filter",option+1,3) == 0)
             {
-              image_info->filter=MitchellFilter;
               if (*option == '-')
                 {
+                  FilterType
+                    filter;
+
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing type",option);
                   option=argv[i];
-                  image_info->filter=UndefinedFilter;
+                  filter=UndefinedFilter;
                   if (Latin1Compare("Point",option) == 0)
-                    image_info->filter=PointFilter;
+                    filter=PointFilter;
                   if (Latin1Compare("Box",option) == 0)
-                    image_info->filter=BoxFilter;
+                    filter=BoxFilter;
                   if (Latin1Compare("Triangle",option) == 0)
-                    image_info->filter=TriangleFilter;
+                    filter=TriangleFilter;
                   if (Latin1Compare("Hermite",option) == 0)
-                    image_info->filter=HermiteFilter;
+                    filter=HermiteFilter;
                   if (Latin1Compare("Hanning",option) == 0)
-                    image_info->filter=HanningFilter;
+                    filter=HanningFilter;
                   if (Latin1Compare("Hamming",option) == 0)
-                    image_info->filter=HammingFilter;
+                    filter=HammingFilter;
                   if (Latin1Compare("Blackman",option) == 0)
-                    image_info->filter=BlackmanFilter;
+                    filter=BlackmanFilter;
                   if (Latin1Compare("Gaussian",option) == 0)
-                    image_info->filter=GaussianFilter;
+                    filter=GaussianFilter;
                   if (Latin1Compare("Quadratic",option) == 0)
-                    image_info->filter=QuadraticFilter;
+                    filter=QuadraticFilter;
                   if (Latin1Compare("Cubic",option) == 0)
-                    image_info->filter=CubicFilter;
+                    filter=CubicFilter;
                   if (Latin1Compare("Catrom",option) == 0)
-                    image_info->filter=CatromFilter;
+                    filter=CatromFilter;
                   if (Latin1Compare("Mitchell",option) == 0)
-                    image_info->filter=MitchellFilter;
+                    filter=MitchellFilter;
                   if (Latin1Compare("Lanczos",option) == 0)
-                    image_info->filter=LanczosFilter;
+                    filter=LanczosFilter;
                   if (Latin1Compare("Bessel",option) == 0)
-                    image_info->filter=BesselFilter;
+                    filter=BesselFilter;
                   if (Latin1Compare("Sinc",option) == 0)
-                    image_info->filter=SincFilter;
-                  if (image_info->filter == UndefinedFilter)
+                    filter=SincFilter;
+                  if (filter == UndefinedFilter)
                     MagickError(OptionError,"Invalid filter type",option);
                 }
               break;
@@ -1394,10 +1396,11 @@ int main(int argc,char **argv)
                   Write image.
                 */
                 (void) strcpy(image->filename,resource_info.write_filename);
+                SetImageInfo(image_info,True);
                 (void) WriteImage(image_info,image);
               }
             if (image_info->verbose)
-              DescribeImage(image,stdout,False);
+              DescribeImage(image,stderr,False);
             /*
               Proceed to next/previous image.
             */
