@@ -60,6 +60,192 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   B e s s e l O r d e r O n e                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method BesselOrderOne computes the Bessel function of x of the first kind
+%  of order 0:
+%
+%    Reduce x to |x| since j1(x)= -j1(-x), and for x in (0,8]
+%
+%       j1(x) = x*j1(x);
+%
+%    For x in (8,inf)
+%
+%       j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x1)-q1(x)*sin(x1))
+%
+%    where x1 = x-3*pi/4. Compute sin(x1) and cos(x1) as follow:
+%
+%       cos(x1) =  cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
+%               =  1/sqrt(2) * (sin(x) - cos(x))
+%       sin(x1) =  sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
+%               = -1/sqrt(2) * (sin(x) + cos(x))
+%
+%  The format of the BesselOrderOne routine is:
+%
+%      value=BesselOrderOne(x)
+%
+%  A description of each parameter follows:
+%
+%    o value: Method BesselOrderOne returns the Bessel function of x of the
+%      first kind of orders 1.
+%
+%    o x: double value.
+%
+%
+*/
+
+static double J1(double x)
+{
+  double
+    p,
+    q;
+
+  register int
+    i;
+
+  static const double
+    Pone[] =
+    {
+       0.581199354001606143928050809e+21,
+      -0.6672106568924916298020941484e+20,
+       0.2316433580634002297931815435e+19,
+      -0.3588817569910106050743641413e+17,
+       0.2908795263834775409737601689e+15,
+      -0.1322983480332126453125473247e+13,
+       0.3413234182301700539091292655e+10,
+      -0.4695753530642995859767162166e+7,
+       0.270112271089232341485679099e+4
+    },
+    Qone[] =
+    {
+      0.11623987080032122878585294e+22,
+      0.1185770712190320999837113348e+20,
+      0.6092061398917521746105196863e+17,
+      0.2081661221307607351240184229e+15,
+      0.5243710262167649715406728642e+12,
+      0.1013863514358673989967045588e+10,
+      0.1501793594998585505921097578e+7,
+      0.1606931573481487801970916749e+4,
+      0.1e+1
+    };
+
+  p=Pone[8];
+  q=Qone[8];
+  for (i=7; i >= 0; i--)
+  {
+    p=p*x*x+Pone[i];
+    q=q*x*x+Qone[i];
+  }
+  return(p/q);
+}
+
+static double P1(double x)
+{
+  double
+    p,
+    q;
+
+  register int
+    i;
+
+  static const double
+    Pone[] =
+    {
+      0.352246649133679798341724373e+5,
+      0.62758845247161281269005675e+5,
+      0.313539631109159574238669888e+5,
+      0.49854832060594338434500455e+4,
+      0.2111529182853962382105718e+3,
+      0.12571716929145341558495e+1
+    },
+    Qone[] =
+    {
+      0.352246649133679798068390431e+5,
+      0.626943469593560511888833731e+5,
+      0.312404063819041039923015703e+5,
+      0.4930396490181088979386097e+4,
+      0.2030775189134759322293574e+3,
+      0.1e+1
+    };
+
+  p=Pone[5];
+  q=Qone[5];
+  for (i=4; i >= 0; i--)
+  {
+    p=p*(8.0/x)*(8.0/x)+Pone[i];
+    q=q*(8.0/x)*(8.0/x)+Qone[i];
+  }
+  return(p/q);
+}
+
+static double Q1(double x)
+{
+  double
+    p,
+    q;
+
+  register int
+    i;
+
+  static const double
+    Pone[] =
+    {
+      0.3511751914303552822533318e+3,
+      0.7210391804904475039280863e+3,
+      0.4259873011654442389886993e+3,
+      0.831898957673850827325226e+2,
+      0.45681716295512267064405e+1,
+      0.3532840052740123642735e-1
+    },
+    Qone[] =
+    {
+      0.74917374171809127714519505e+4,
+      0.154141773392650970499848051e+5,
+      0.91522317015169922705904727e+4,
+      0.18111867005523513506724158e+4,
+      0.1038187585462133728776636e+3,
+      0.1e+1
+    };
+
+  p=Pone[5];
+  q=Qone[5];
+  for (i=4; i >= 0; i--)
+  {
+    p=p*(8.0/x)*(8.0/x)+Pone[i];
+    q=q*(8.0/x)*(8.0/x)+Qone[i];
+  }
+  return(p/q);
+}
+
+Export double BesselOrderOne(double x)
+{
+  double
+    p,
+    q;
+
+  if (x == 0.0)
+    return(0.0);
+  p=x;
+  if (x < 0.0)
+    x=(-x);
+  if (x < 8.0)
+    return(p*J1(x));
+  q=sqrt(2.0/(M_PI*x))*(P1(x)*(1.0/sqrt(2.0)*(sin(x)-cos(x)))-8.0/x*Q1(x)*
+    (-1.0/sqrt(2.0)*(sin(x)+cos(x))));
+  if (p < 0.0)
+    q=(-q);
+  return(q);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   C o n s t r a s t                                                         %
 %                                                                             %
 %                                                                             %
@@ -69,7 +255,7 @@
 %  Method Contrast enhances the intensity differences between the lighter
 %  and darker elements of the image.
 %
-%  The format of the ContrastImage routine is:
+%  The format of the Contrast routine is:
 %
 %      Contrast(sign,red,green,blue)
 %
@@ -517,7 +703,7 @@ static unsigned short PixelOnLine(const PointInfo *pixel,
         alpha;
 
       alpha=sqrt(distance)-mid-0.5;
-      return((unsigned short) Max(opacity,Opaque*alpha*alpha));
+      return((unsigned short) Max((int) opacity,Opaque*alpha*alpha));
     }
   return(opacity);
 }
@@ -610,13 +796,15 @@ Export unsigned short InsidePrimitive(PrimitiveInfo *primitive_info,
         radius=sqrt(alpha*alpha+beta*beta);
         beta=fabs(distance-radius);
         if (beta < (mid+0.5))
-          if (beta <= (mid-0.5))
-            opacity=Opaque;
-          else
-            {
-              alpha=mid-beta+0.5;
-              opacity=(unsigned short) Max(opacity,Opaque*alpha*alpha);
-            }
+          {
+            if (beta <= (mid-0.5))
+              opacity=Opaque;
+            else
+              {
+                alpha=mid-beta+0.5;
+                opacity=(unsigned short) Max((int) opacity,Opaque*alpha*alpha);
+              }
+          }
         break;
       }
       case FillCirclePrimitive:
@@ -633,7 +821,7 @@ Export unsigned short InsidePrimitive(PrimitiveInfo *primitive_info,
           if (distance < (radius+1.0))
             {
               alpha=(radius-distance+1.0)/2.0;
-              opacity=(unsigned short) Max(opacity,Opaque*alpha*alpha);
+              opacity=(unsigned short) Max((int) opacity,Opaque*alpha*alpha);
             }
         break;
       }
@@ -795,7 +983,7 @@ Export unsigned short InsidePrimitive(PrimitiveInfo *primitive_info,
                 target.green=XDownScale(border_color.green);
                 target.blue=XDownScale(border_color.blue);
               }
-            ColorFloodfillImage(image,&target,annotate_info->image_info->pen,
+            ColorFloodfillImage(image,&target,annotate_info->tile,
               (int) pixel->x,(int) pixel->y,p->method);
             break;
           }
@@ -1169,8 +1357,7 @@ Export void TransformHSL(const Quantum red,const Quantum green,
   delta=max-min;
   if (delta == 0.0)
     return;
-  *saturation=delta;
-  *saturation/=(*luminosity <= 0.5) ? (min+max) : (2.0-max-min) ;
+  *saturation=delta/((*luminosity <= 0.5) ? (min+max) : (2.0-max-min));
   if (r == max)
     *hue=(g == min ? 5.0+(max-b)/delta : 1.0-(max-g)/delta);
   else
