@@ -74,7 +74,7 @@ typedef struct _FilterInfo
 {
   double
     (*function)(double),
-    width;
+    support;
 } FilterInfo;
 
 typedef struct _FrameInfo
@@ -149,7 +149,7 @@ typedef struct _ImageInfo
     units;
 
   FilterType
-    filter;
+    filter;  /* no longer used */
 
   PreviewType
     preview_type;
@@ -400,6 +400,9 @@ typedef struct _Image
   FilterType
     filter;
 
+  double
+    blur;
+
   unsigned long
     total_colors;
 
@@ -468,9 +471,6 @@ extern const char
   *ReadBinaryType,
   *ReadBinaryUnbufferedType,
   *WriteBinaryType;
-
-extern const double
-  SharpenFactor;
 
 /*
   Image utilities methods.
