@@ -54,7 +54,7 @@
 %  Usage: mogrify [options ...] file [ [options ...] file ...]
 %
 %  Where options include:
-%    -antialias               remove pixelaliasing
+%    -antialias           remove pixel-aliasing
 %    -blur factor         apply a filter to blur the image
 %    -border geometry     surround image with a border of color
 %    -box color           color for annotation bounding box
@@ -176,7 +176,7 @@ static void Usage(const char *client_name)
   static const char
     *options[]=
     {
-      "-antialias               remove pixelaliasing",
+      "-antialias           remove pixel-aliasing",
       "-blur factor         apply a filter to blur the image",
       "-border geometry     surround image with a border of color",
       "-box color           color for annotation bounding box",
@@ -662,45 +662,47 @@ int main(int argc,char **argv)
         {
           if (strncmp("filter",option+1,3) == 0)
             {
-              image_info.filter=MitchellFilter;
               if (*option == '-')
                 {
+                  FilterType
+                    filter;
+
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing type",option);
                   option=argv[i];
-                  image_info.filter=UndefinedFilter;
+                  filter=UndefinedFilter;
                   if (Latin1Compare("Point",option) == 0)
-                    image_info.filter=PointFilter;
+                    filter=PointFilter;
                   if (Latin1Compare("Box",option) == 0)
-                    image_info.filter=BoxFilter;
+                    filter=BoxFilter;
                   if (Latin1Compare("Triangle",option) == 0)
-                    image_info.filter=TriangleFilter;
+                    filter=TriangleFilter;
                   if (Latin1Compare("Hermite",option) == 0)
-                    image_info.filter=HermiteFilter;
+                    filter=HermiteFilter;
                   if (Latin1Compare("Hanning",option) == 0)
-                    image_info.filter=HanningFilter;
+                    filter=HanningFilter;
                   if (Latin1Compare("Hamming",option) == 0)
-                    image_info.filter=HammingFilter;
+                    filter=HammingFilter;
                   if (Latin1Compare("Blackman",option) == 0)
-                    image_info.filter=BlackmanFilter;
+                    filter=BlackmanFilter;
                   if (Latin1Compare("Gaussian",option) == 0)
-                    image_info.filter=GaussianFilter;
+                    filter=GaussianFilter;
                   if (Latin1Compare("Quadratic",option) == 0)
-                    image_info.filter=QuadraticFilter;
+                    filter=QuadraticFilter;
                   if (Latin1Compare("Cubic",option) == 0)
-                    image_info.filter=CubicFilter;
+                    filter=CubicFilter;
                   if (Latin1Compare("Catrom",option) == 0)
-                    image_info.filter=CatromFilter;
+                    filter=CatromFilter;
                   if (Latin1Compare("Mitchell",option) == 0)
-                    image_info.filter=MitchellFilter;
+                    filter=MitchellFilter;
                   if (Latin1Compare("Lanczos",option) == 0)
-                    image_info.filter=LanczosFilter;
+                    filter=LanczosFilter;
                   if (Latin1Compare("Bessel",option) == 0)
-                    image_info.filter=BesselFilter;
+                    filter=BesselFilter;
                   if (Latin1Compare("Sinc",option) == 0)
-                    image_info.filter=SincFilter;
-                  if (image_info.filter == UndefinedFilter)
+                    filter=SincFilter;
+                  if (filter == UndefinedFilter)
                     MagickError(OptionError,"Invalid filter type",option);
                 }
               break;
@@ -1416,6 +1418,7 @@ int main(int argc,char **argv)
           (void) strcpy(p->filename,image->filename);
           p->scene=scene++;
         }
+        SetImageInfo(&image_info,True);
         for (p=image; p != (Image *) NULL; p=p->next)
         {
           status=WriteImage(&image_info,p);
@@ -1425,7 +1428,7 @@ int main(int argc,char **argv)
         for (p=image; p != (Image *) NULL; p=p->next)
           scene--;
         if (image_info.verbose)
-          DescribeImage(image,stdout,False);
+          DescribeImage(image,stderr,False);
         if ((format == (char *) NULL) && (status != False))
           if (Latin1Compare(image_info.filename,"-") != 0)
             {
