@@ -88,6 +88,7 @@
 %
 %  Where options include:
 %    -adjoin             join images into a single multi-image file
+%    -blur factor        apply a filter to blur the image
 %    -colors value       preferred number of colors in the image
 %    -colorspace type    alternate image colorspace
 %    -comment string     annotate image with comment
@@ -116,6 +117,7 @@
 %    -rotate degrees     apply Paeth rotation to the image
 %    -scene value        image scene number
 %    -shadow             add a shadow beneath a tile to simulate depth
+%    -sharpen factor     apply a filter to sharpen the image
 %    -size geometry      width and height of image
 %    -texture filename   name of texture to tile onto the image background
 %    -tile geometry      number of tiles per row and column
@@ -173,6 +175,7 @@ static void Usage(const char *client_name)
     *options[]=
     {
       "-adjoin             join images into a single multi-image file",
+      "-blur factor        apply a filter to blur the image",
       "-colors value       preferred number of colors in the image",
       "-colorspace type    alternate image colorsapce",
       "-comment string     annotate image with comment",
@@ -340,6 +343,16 @@ int main(int argc,char **argv)
                 }
               break;
             }
+          if (strncmp("blur",option+1,3) == 0)
+            {
+              if (*option == '-')
+                {
+                  i++;
+                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
+                    MagickError(OptionError,"Missing factor",option);
+                }
+              break;
+            }
           if (strncmp("bordercolor",option+1,7) == 0)
             {
               image_info.border_color=(char *) NULL;
@@ -587,45 +600,47 @@ int main(int argc,char **argv)
         {
           if (strncmp("filter",option+1,3) == 0)
             {
-              image_info.filter=MitchellFilter;
               if (*option == '-')
                 {
+                  FilterType
+                    filter;
+
                   i++;
                   if (i == argc)
                     MagickError(OptionError,"Missing type",option);
                   option=argv[i];
-                  image_info.filter=UndefinedFilter;
+                  filter=UndefinedFilter;
                   if (Latin1Compare("Point",option) == 0)
-                    image_info.filter=PointFilter;
+                    filter=PointFilter;
                   if (Latin1Compare("Box",option) == 0)
-                    image_info.filter=BoxFilter;
+                    filter=BoxFilter;
                   if (Latin1Compare("Triangle",option) == 0)
-                    image_info.filter=TriangleFilter;
+                    filter=TriangleFilter;
                   if (Latin1Compare("Hermite",option) == 0)
-                    image_info.filter=HermiteFilter;
+                    filter=HermiteFilter;
                   if (Latin1Compare("Hanning",option) == 0)
-                    image_info.filter=HanningFilter;
+                    filter=HanningFilter;
                   if (Latin1Compare("Hamming",option) == 0)
-                    image_info.filter=HammingFilter;
+                    filter=HammingFilter;
                   if (Latin1Compare("Blackman",option) == 0)
-                    image_info.filter=BlackmanFilter;
+                    filter=BlackmanFilter;
                   if (Latin1Compare("Gaussian",option) == 0)
-                    image_info.filter=GaussianFilter;
+                    filter=GaussianFilter;
                   if (Latin1Compare("Quadratic",option) == 0)
-                    image_info.filter=QuadraticFilter;
+                    filter=QuadraticFilter;
                   if (Latin1Compare("Cubic",option) == 0)
-                    image_info.filter=CubicFilter;
+                    filter=CubicFilter;
                   if (Latin1Compare("Catrom",option) == 0)
-                    image_info.filter=CatromFilter;
+                    filter=CatromFilter;
                   if (Latin1Compare("Mitchell",option) == 0)
-                    image_info.filter=MitchellFilter;
+                    filter=MitchellFilter;
                   if (Latin1Compare("Lanczos",option) == 0)
-                    image_info.filter=LanczosFilter;
+                    filter=LanczosFilter;
                   if (Latin1Compare("Bessel",option) == 0)
-                    image_info.filter=BesselFilter;
+                    filter=BesselFilter;
                   if (Latin1Compare("Sinc",option) == 0)
-                    image_info.filter=SincFilter;
-                  if (image_info.filter == UndefinedFilter)
+                    filter=SincFilter;
+                  if (filter == UndefinedFilter)
                     MagickError(OptionError,"Invalid filter type",option);
                 }
               break;
@@ -962,6 +977,16 @@ int main(int argc,char **argv)
                 }
               break;
             }
+          if (strncmp("sharpen",option+1,5) == 0)
+            {
+              if (*option == '-')
+                {
+                  i++;
+                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
+                    MagickError(OptionError,"Missing factor",option);
+                }
+              break;
+            }
           MagickError(OptionError,"Unrecognized option",option);
           break;
         }
@@ -1133,6 +1158,7 @@ int main(int argc,char **argv)
       }
     (void) strcpy(p->filename,argv[argc-1]);
   }
+  SetImageInfo(&image_info,True);
   for (p=montage_image; p != (Image *) NULL; p=p->next)
   {
     (void) WriteImage(&image_info,p);
